unit TransLT.API;

//Interface for TransLT library version 14.0.0.6

interface

{$IFDEF TOPOLT}
  {$IFDEF WIN64}
      const TRLTDLLFILE = 'TransLT\TransLT.Win64.dll';
  {$ELSE}
    {$IFDEF WIN32}
      const TRLTDLLFILE = 'TransLT\TransLT.Win32.dll';
    {$ENDIF}
  {$ENDIF}
{$ELSE}
  {$IFDEF WIN64}
      const TRLTDLLFILE = '..\..\..\Library\Win64\TransLT.Win64.dll';
  {$ELSE}
    {$IFDEF WIN32}
      const TRLTDLLFILE = '..\..\..\Library\Win32\TransLT.Win32.dll';
    {$ENDIF}
  {$ENDIF}
{$ENDIF}

const
  MY_PLACE_INI_TEXT   = 'My Place';
  MAX_LEN_NAMES       = 255;
  MAX_LEN_AXES        = 6;
  MAX_LEN_HTML_COLOR  = 8;
  MAX_LEN_FOLDER_NAME = 32;
  MAX_LEN_ENTITY_INFO = 32;
  MAX_LEN_ENTITY_DESC = 128;

{$Z4}  //The $Z compiler directive sets the minimum storage size, in bytes,
       //that enumerated types will take (used for compatibility with MSVC++).

type
  BOOL = LongBool;

//----------------------------------------------------------------------------------------------------------------------

  /// <summary>
  ///   Is a type of callback function called used internally by the
  ///   TransformPoints and TransformPointsOfAllGEEntities. In these commands
  ///   percentage is increased from 0 to 100.
  /// </summary>
  TProgressProc = procedure (const Procent: integer); stdcall;

//----------------------------------------------------------------------------------------------------------------------

  /// <summary>
  ///   Enumeration of encoding types.
  /// </summary>
  TEncodingType = (
    ///	<summary>
    ///	  ANSI
    ///	</summary>
    etANSI,

    ///	<summary>
    ///	  UTF8
    ///	</summary>
    etUTF8,

    ///	<summary>
    ///	  Unicode
    ///	</summary>
    etUnicode,

    ///	<summary>
    ///	  Unicode Big Endian
    ///	</summary>
    etBigEndianUnicode
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Plainunits typeused for length orperimeter of entities.
  ///	</summary>
  TPlainUnits = (
    ///	<summary>
    ///	  [km] Kilometer
    ///	</summary>
    puKilometer,

    ///	<summary>
    ///	  [m] Meter
    ///	</summary>
    puMeter,

    ///	<summary>
    ///	  [dm] Decimeter
    ///	</summary>
    puDeciMeter,

    ///	<summary>
    ///	  [cm] Centimeter
    ///	</summary>
    puCentiMeter,

    ///	<summary>
    ///	  [mm] Millimeter
    ///	</summary>
    puMilliMeter,

    ///	<summary>
    ///	  [kmi] International Nautical Mile
    ///	</summary>
    puIntlNauticalMile,

    ///	<summary>
    ///	  [in] International Inch
    ///	</summary>
    puIntlInch,

    ///	<summary>
    ///	  [ft] International Foot
    ///	</summary>
    puIntlFoot,

    ///	<summary>
    ///	  [yd] International Yard
    ///	</summary>
    puIntlYard,

    ///	<summary>
    ///	  [mi] International Statute Mile
    ///	</summary>
    puIntlStatuteMile,

    ///	<summary>
    ///	  [fath] International Fathom
    ///	</summary>
    puIntlFathom,

    ///	<summary>
    ///	  [ch] International Chain
    ///	</summary>
    puIntlChain,

    ///	<summary>
    ///	  [link] International Link
    ///	</summary>
    puIntlLink,

    ///	<summary>
    ///	  [us-in] U.S. Surveyors Inch
    ///	</summary>
    puUSSurvInch,

    ///	<summary>
    ///	  [us-ft] U.S. Surveyors Foot
    ///	</summary>
    puUSSurvFoot,

    ///	<summary>
    ///	  [us-yd] U.S. Surveyors Yard
    ///	</summary>
    puUSSurvYard,

    ///	<summary>
    ///	  [us-ch] U.S. Surveyors Chain
    ///	</summary>
    puUSSurvChain,

    ///	<summary>
    ///	  [us-mi] U.S. Surveyors Statute Mile
    ///	</summary>
    puUSSurvStatuteMile,

    ///	<summary>
    ///	  [ind-yd] Indian Yard
    ///	</summary>
    puIndianYard,

    ///	<summary>
    ///	  [ind-ft] Indian Foot
    ///	</summary>
    puIndianFoot,

    ///	<summary>
    ///	  [ind-ch] Indian Chain
    ///	</summary>
    puIndianChain,

    ///	<summary>
    ///	  [us-lk] U.S. Surveyors Link
    ///	</summary>
    puSurvLink,

    ///	<summary>
    ///	  [clk-ft] Clarkes Foot
    ///	</summary>
    puClarkeFoot,

    ///	<summary>
    ///	  [clk-yd] Clarkes Yard
    ///	</summary>
    puClarkeYard,

    ///	<summary>
    ///	  [clk-lk] Clarkes Link
    ///	</summary>
    puClarkeLink,

    ///	<summary>
    ///	  [clk-ch] Clarkes Chain
    ///	</summary>
    puClarkeChain
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Area units type used for entities.
  ///	</summary>
  TAreaUnits = (
    ///	<summary>
    ///	  [km^2] Square Kilometer
    ///	</summary>
    auSqKilometer,

    ///	<summary>
    ///	  [m^2] Square Meter
    ///	</summary>
    auSqMeter,

    ///	<summary>
    ///	  [dm^2] Square Decimeter
    ///	</summary>
    auSqDeciMeter,

    ///	<summary>
    ///	  [cm^2] Square Centimeter
    ///	</summary>
    auSqCentiMeter,

    ///	<summary>
    ///	  [mm^2] Square Millimeter
    ///	</summary>
    auSqMilliMeter,

    ///	<summary>
    ///	  [a] Ares
    ///	</summary>
    auAres,

    ///	<summary>
    ///	  [ha] Hectares
    ///	</summary>
    auHectares,

    ///	<summary>
    ///	  [ac] International Acres
    ///	</summary>
    auIntlAcres,

    ///	<summary>
    ///	  [sq.in] Square International Inch
    ///	</summary>
    auSqIntlInch,

    ///	<summary>
    ///	  [sq.ft] Square International Foot
    ///	</summary>
    auSqIntlFoot,

    ///	<summary>
    ///	  [sq.yd] Square International Yard
    ///	</summary>
    auSqIntlYard,

    ///	<summary>
    ///	  [sq.mi] Square International Statute Mile
    ///	</summary>
    auSqIntlStatuteMile,

    ///	<summary>
    ///	  [us-ac] U.S. Surveyors Acres
    ///	</summary>
    auUSSurvAcres,

    ///	<summary>
    ///	  [sq.us-in] Square U.S. Surveyors Inch
    ///	</summary>
    auSqUSSurvInch,

    ///	<summary>
    ///	  [sq.us-ft] Square U.S. Surveyors Foot
    ///	</summary>
    auSqUSSurvFoot,

    ///	<summary>
    ///	  [sq.us-yd] Square U.S. Surveyors Yard
    ///	</summary>
    auSqUSSurvYard,

    ///	<summary>
    ///	  [sq.us-mi] Square U.S. Surveyors Statute Mile
    ///	</summary>
    auSqUSSurvStatuteMile,

    ///	<summary>
    ///	  [sq.ind-yd] Square Indian Yard
    ///	</summary>
    auSqIndianYard,

    ///	<summary>
    ///	  [sq.ind-ft] Square Indian Foot
    ///	</summary>
    auSqIndianFoot
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Type of Coordinate Reference System (CRS).
  ///	</summary>
  TCRStype = (
    ///	<summary>
    ///	  Geocentric (X,Y,Z).
    ///	</summary>
    ctXYZ,

    ///	<summary>
    ///	  Geographic (Phi,Lambda) or (Phi,Lambda,He).
    ///	</summary>
    ctGeo,

    ///	<summary>
    ///	  Projected (N,E) or (N,E,H).
    ///	</summary>
    ctNEH
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Type of Coordinate Reference System (CRS) dimension.
  ///	</summary>
  TCRSdimension = (
    ///	<summary>
    ///	  Dimension 2D: (Phi,Lambda) or (N,E).
    ///	</summary>
    cd2D,

    ///	<summary>
    ///	  Dimension 3D: (X,Y,Z), (Phi,Lambda,He) or (N,E,H).
    ///	</summary>
    cd3D
  );

  ///	<summary>
  ///	  Type of draw labels.
  ///	</summary>
  TDrawLabelType = (
    ///	<summary>
    ///	  Default: Draw or not labels is used from PlgDrawLabels from TGEDrawOptions.
    ///	</summary>
    dltDefault,

    ///	<summary>
    ///	  Not Draw: Labels will not be drawn regardless of the general setting from
    ///   PlgDrawLabels from TGEDrawOptions.
    ///	</summary>
    dltNotDraw,

    ///	<summary>
    ///	  Draw: Labels will be drawn regardless of the general setting from
    ///   PlgDrawLabels from TGEDrawOptions.
    ///	</summary>
    dltDraw
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for names. Null-terminated string with maximum 255
  ///	  characters.
  ///	</summary>
  TCharArrayNames = array [0..MAX_LEN_NAMES-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for axes name. Null-terminated string with maximum
  ///	  6 characters.
  ///	</summary>
  TCharArrayAxes  = array [0..MAX_LEN_AXES-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure withall properties of a transformation model.
  ///	</summary>
  TModelDescription = record

    ///	<summary>
    ///	  Model name
    ///	</summary>
    ModelName         : TCharArrayNames;

    ///	<summary>
    ///	  Model description
    ///	</summary>
    TransDescription  : TCharArrayNames;

    ///	<summary>
    ///	  Initial Coordinate System Name
    ///	</summary>
    CooSysIniName     : TCharArrayNames;

    ///	<summary>
    ///	  Final Coordinate System Name
    ///	</summary>
    CooSysFinName     : TCharArrayNames;

    ///	<summary>
    ///	  Initial Coordinate Reference System Type
    ///	</summary>
    CooSysIniType     : TCRStype;

    ///	<summary>
    ///	  Final Coordinate System Type
    ///	</summary>
    CooSysFinType     : TCRStype;

    ///	<summary>
    ///	  Initial Coordinate System Dimension
    ///	</summary>
    CooSysIniDim      : TCRSdimension;

    ///	<summary>
    ///	  Final Coordinate System Dimension
    ///	</summary>
    CooSysFinDim      : TCRSdimension;

    ///	<summary>
    ///	  CRS code for initial system from EPSG database
    ///	</summary>
    CodeCRSini        : integer;

    ///	<summary>
    ///	  CRS code for final system from EPSG database
    ///	</summary>
    CodeCRSfin        : integer;

    ///	<summary>
    ///	  Alternative name for the North axis, the initial system
    ///	</summary>
    AltNameAxisNini   : TCharArrayAxes;

    ///	<summary>
    ///	  Alternative name for the East axis, the initial system
    ///	</summary>
    AltNameAxisEini   : TCharArrayAxes;

    ///	<summary>
    ///	  Alternative name for the North axis, the final system
    ///	</summary>
    AltNameAxisNfin   : TCharArrayAxes;

    ///	<summary>
    ///	  Alternative name for the East axis, the final system
    ///	</summary>
    AltNameAxisEfin   : TCharArrayAxes;

    ///	<summary>
    ///	  Total accuracy of the transformation
    ///	</summary>
    TotalAcurracy     : double;

    ///	<summary>
    ///	  If the model supports or not the reverse transformation
    ///	</summary>
    SupportReverseCalc: BOOL;

    ///	<summary>
    ///	  If the model is time-dependent and if necessary the introduction of the epoch
    ///	</summary>
    IsTimeDependent   : BOOL;

    ///	<summary>
    ///	  If the model use time epoch and if necessary the introduction of the epoch T0
    ///	</summary>
    IsUseTimeEpochT0   : BOOL;
  end;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for Html color. Null-terminated string with
  ///	  maximum8 characters.
  ///	</summary>
  TCharArrayHtmlColor  = array [0..MAX_LEN_HTML_COLOR-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for Google Earth folder names. Null-terminated
  ///	  string with maximum32 characters.
  ///	</summary>
  TCharArrayFolderName = array [0..MAX_LEN_FOLDER_NAME-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure of all drawing options in Google Earth.
  ///	</summary>
  ///	<remarks>
  ///	  Thecorrection can be used only if the transformation is less accurate,
  ///	  otherwise the value must be 0.0.
  ///	</remarks>
  TGEDrawOptions = record

    ///	<summary>
    ///	  Color and opacity for all polygons labels (Polygon Number).
    ///	</summary>
    PlgLabelsHtmlColor : TCharArrayHtmlColor;

    ///	<summary>
    ///	  Color and opacity for all polygons lines.
    ///	</summary>
    PlgLinesHtmlColor  : TCharArrayHtmlColor;

    ///	<summary>
    ///	  Draw or not labels for all polygons.
    ///	</summary>
    PlgDrawLabels      : BOOL;

    ///	<summary>
    ///	  Add area value to entity name for polygons.
    ///	</summary>
    PlgAddAreaToName: BOOL;

    ///	<summary>
    ///	  Color and opacity for all path labels (Start and End texts).
    ///	</summary>
    PathLabelsHtmlColor: TCharArrayHtmlColor;

    ///	<summary>
    ///	  Draw or not labels for all paths
    ///	</summary>
    PathDrawLabels     : BOOL;

    ///	<summary>
    ///	  Add length value to entity name for paths.
    ///	</summary>
    PathAddLengthToName: BOOL;

    ///	<summary>
    ///	  Index of symbol image for start and end points, [0..11] see images in
    ///	  TransLT in Option form.
    ///	</summary>
    PathIdxSymbIcon    : integer;

    ///	<summary>
    ///	  Color and opacity for all points labels from group.
    ///	</summary>
    PtsLabelsHtmlColor : TCharArrayHtmlColor;

    ///	<summary>
    ///	  Add text description to entity name.
    ///	</summary>
    AddDescrToName : BOOL;

    ///	<summary>
    ///	  Distance from which are seen all labels, necessary when used double
    ///	  click on the label in Google Earth.
    ///	</summary>
    LabelsDistToViewKm : double;

    ///	<summary>
    ///	  Folder name for polygons.
    ///	</summary>
    FoldPlg            : TCharArrayFolderName;

    ///	<summary>
    ///	  Folder name for paths.
    ///	</summary>
    FoldPath           : TCharArrayFolderName;

    ///	<summary>
    ///	  Folder name for points grup.
    ///	</summary>
    FoldGrpPts         : TCharArrayFolderName;

    ///	<summary>
    ///	  Correction to adjust the latitude on save.
    ///	</summary>
    CorPhi             : double;

    ///	<summary>
    ///	  Correction to adjust the longitude on save.
    ///	</summary>
    ///	<remarks>
    ///	  The correction can be used only if the transformation is less
    ///	  accurate, otherwise the value must be 0.0.
    ///	</remarks>
    CorLam             : double;
  end;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Entity type
  ///	</summary>
  TEntityType = (
    ///	<summary>
    ///	  Polygon
    ///	</summary>
    etPolygon,

    ///	<summary>
    ///	  Path
    ///	</summary>
    etPath,

    ///	<summary>
    ///	  Points group
    ///	</summary>
    etGrpPts
  );

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for entity text info. Null-terminated string with
  ///	  maximum 32 characters.
  ///	</summary>
  TCharArrayEntityInfo = array [0..MAX_LEN_ENTITY_INFO-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for entity description. Null-terminated string
  ///	  with maximum128 characters.
  ///	</summary>
  TCharArrayEntityDesc = array [0..MAX_LEN_ENTITY_DESC-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure withall properties of anentity.
  ///	</summary>
  TGEEntityProperties = record

    ///	<summary>
    ///	  Entity type: polygon, path or points group.
    ///	</summary>
    EntityType   : TEntityType;

    ///	<summary>
    ///	  Polygon Number, Start Text for path or Group Name for points.
    ///	</summary>
    Info1        : TCharArrayEntityInfo;

    ///	<summary>
    ///	  Polygon Description or End Text for path.
    ///	</summary>
    Info2        : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Area, used only for polygon.
    ///	</summary>
    InfoA        : TCharArrayEntityInfo;

    ///	<summary>
    ///	  Perimeter for polygon or Length for path.
    ///	</summary>
    InfoL        : TCharArrayEntityInfo;

    ///	<summary>
    ///	  Add in parentheses the area to the text of the polygon label.
    ///	</summary>
    AddAtoName   : BOOL;

    ///	<summary>
    ///	  Add in parentheses the length to the text of the path label.
    ///	</summary>
    AddLtoName   : BOOL;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd1       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd2       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd3       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd4       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd5       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Additional information.
    ///	</summary>
    InfoAd6       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Index of symbol image for points, used only for points group, [0..11]
    ///	  see images in TransLT in Option form.
    ///	</summary>
    IdxImgSymb   : integer;

    ///	<summary>
    ///	  Fill color and opacity for polygon, color and opacity for path lines
    ///	  or fill color and opacity for symbol of points.
    ///	</summary>
    HtmlColor    : TCharArrayHtmlColor;

    ///	<summary>
    ///   Fill color and opacity only for polygon lines.
    ///   For empty string is used PlgLinesHtmlColor from TGEDrawOptions.
    ///	</summary>
    HtmlLineColor: TCharArrayHtmlColor;

    ///	<summary>
    ///	  Width of the lines for polygon and path (Value &gt;= 0.0).
    ///	</summary>
    LinesWidth: double;

    ///	<summary>
    ///   Only for polygons draw or not label or use default draw labels PlgDrawLabels
    ///   from TGEDrawOptions.
    ///	</summary>
    DrawLabel: TDrawLabelType;

    ///	<summary>
    ///   Fill color and opacity for polygon labels and group points labels.
    ///   For empty string is used PlgLabelsHtmlColor from TGEDrawOptions.
    ///	</summary>
    HtmlLabelColor: TCharArrayHtmlColor;

    ///	<summary>
    ///	  Label scale factor for polygons and points.
    ///	</summary>
    LabelScale: double;

    ///	<summary>
    ///	  Symbol scale factor for points.
    ///	</summary>
    SymbolScale: double;

    ///	<summary>
    ///	  Display information about the entity.
    ///	</summary>
    UseAddBox    : BOOL;

    ///	<summary>
    ///	  Add information about Polygon Number, etc.
    ///	</summary>
    UseAddInfo1  : BOOL;

    ///	<summary>
    ///	  Add information about Polygon Description, etc.
    ///	</summary>
    UseAddInfo2  : BOOL;

    ///	<summary>
    ///	  Add information about Polygon Area.
    ///	</summary>
    UseAddInfoA  : BOOL;

    ///	<summary>
    ///	  Add information about Perimeter or Length.
    ///	</summary>
    UseAddInfoL  : BOOL;

    ///	<summary>
    ///	  Add address of the entity.
    ///	</summary>
    UseAddAdr    : BOOL;

    ///	<summary>
    ///	  Text of address.
    ///	</summary>
    AddAdr       : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Add destination of the entity.
    ///	</summary>
    UseAddDest   : BOOL;

    ///	<summary>
    ///	  Text of destination.
    ///	</summary>
    AddDest      : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Add usage of the entity.
    ///	</summary>
    UseAddUsage  : BOOL;

    ///	<summary>
    ///	  Text of usage.
    ///	</summary>
    AddUsage     : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Add URL link of the entity.
    ///	</summary>
    UseAddLnk    : BOOL;

    ///	<summary>
    ///	  Text of page name.
    ///	</summary>
    AddLinkName  : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Text of URL link.
    ///	</summary>
    AddLinkURL   : TCharArrayEntityDesc;

    ///	<summary>
    ///	  Entity subfolder.
    ///	</summary>
    SubFolder   : TCharArrayFolderName;
  end;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  WideChar buffer used for entity language words. Null-terminated string
  ///	  with maximum32 characters.
  ///	</summary>
  TCharArrayLangWords = array [0..MAX_LEN_ENTITY_INFO-1] of WideChar;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure withlanguage words used to define entities.
  ///	</summary>
  TGEEntLangWords = record

    ///	<summary>
    ///	  Text with "My Place" (in english).
    ///	</summary>
    StrEntMyPlace      : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Polygon - No name" (in english).
    ///	</summary>
    StrEntPolygonNoName: TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Path - No name" (in english).
    ///	</summary>
    StrEntPathNoName   : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Group points - No name" (in english).
    ///	</summary>
    StrEntGrpPtsNoName : TCharArrayLangWords;
  end;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure withlanguage words used for properties of entities.
  ///	</summary>
  TGEKmlLangWords = record

    ///	<summary>
    ///	  Text with "Number" (in english).
    ///	</summary>
    StrKmlPlgNumber    : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Start" (in english).
    ///	</summary>
    StrKmlPathStart    : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "End" (in english).
    ///	</summary>
    StrKmlPathEnd      : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Group name" (in english).
    ///	</summary>
    StrKmlGrpPtsName   : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Description" (in english).
    ///	</summary>
    StrKmlDescription  : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Area" (in english).
    ///	</summary>
    StrKmlArea         : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Perimeter" (in english).
    ///	</summary>
    StrKmlPerimeter    : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Length" (in english).
    ///	</summary>
    StrKmlLength       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd1       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd2       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd3       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd4       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd5       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Additional information" (in english).
    ///	</summary>
    StrKmlInfoAd6       : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Information" (in english).
    ///	</summary>
    StrKmlInformation  : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Address" (in english).
    ///	</summary>
    StrKmlAddress      : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Destination" (in english).
    ///	</summary>
    StrKmlDestination  : TCharArrayLangWords;

    ///	<summary>
    ///	  Text with "Usage" (in english).
    ///	</summary>
    StrKmlUsage        : TCharArrayLangWords;
  end;

//----------------------------------------------------------------------------------------------------------------------

  ///	<summary>
  ///	  Structure which defines the format of writing angles.
  ///	</summary>
  TAngleAspect = record

    ///	<summary>
    ///	  Usedecimal degrees (0.000000000000 or 000'0.000000").
    ///	</summary>
    UseDecDeg : BOOL;

    ///	<summary>
    ///	  Use signs N and S for latitude, E and W for longitude instead of plus
    ///	  and minus. This setting is possible only when not using decimal
    ///	  degrees.
    ///	</summary>
    UseNSEW   : BOOL;

    ///	<summary>
    ///	  Character for degree, [] or [d].
    ///	</summary>
    ChDeg     : WideChar;

    ///	<summary>
    ///	  Character for minutes, ex. ['] or [m].
    ///	</summary>
    ChMin     : WideChar;

    ///	<summary>
    ///	  Character for seconds, ex. ["] or [s].
    ///	</summary>
    ChSec     : WideChar;

    ///	<summary>
    ///	  Decimals for seconds. For decimal degrees is added 6 to this number.
    ///	</summary>
    DecNoSec  : integer;
  end;

{$Z1}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

///	<summary>
///	  Sets the text file with the error messages. All error messagesare read
///	  from this file.
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function SetErrMsgFileName(const lpFileName: PWideChar): boolean; stdcall;
{$EXTERNALSYM SetErrMsgFileName}

///	<summary>
///	  Returns the file name of the error messages that was previously allocated
///	  with SetErrMsgFileName.
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a WideChar buffer that containing the transformation model
///	  file name.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpFileName buffer.
///	</param>
procedure GetErrMsgFileName(var lpFileName: PWideChar; var nMaxCount: integer); stdcall;
{$EXTERNALSYM GetErrMsgFileName}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

///	<summary>
///	  Check if the file contains transformation models, if the models has
///	  coordinate operations and the file version.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file withmtr, mtrs or xml extension. Files can be
///	  created and savedwith TransLT program.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function ModelFileIsCompatible(const lpModelFileName: PWideChar): boolean; stdcall;
{$EXTERNALSYM ModelFileIsCompatible}

///	<summary>
///	  Checkif the transformation modelfrom a file has defined coordinate
///	  operations (if it has transformation steps).
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension)this value is
///	  always 1 and for those with more models (files with mtrs extension) can
///	  be 1 up.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function ModelHasCooOperations(const lpModelFileName: PWideChar; const ModelIndex: integer;
                               var ErrNo: integer;
                               var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM ModelHasCooOperations}

///	<summary>
///	  Check if the transformation model selected from a file is reversible or
///	  not.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension) this value is
///	  always 1 and for those with more models (files with mtrs or xml extension) can
///	  be 1 up.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer toa WideChar buffer that containing themessage error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function ModelIsReversible(const lpModelFileName: PWideChar; const ModelIndex: integer;
                           var ErrNo: integer;
                           var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM ModelIsReversible}

///	<summary>
///	  Check ifthe transformation model selected from a file is compatible for
///	  drawing in Google Earth
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension) this value is
///	  always 1 and for those with more models (files with mtrs or xml extension) can
///	  be 1 up.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  <para>
///	    Only models that makes a transformation:
///	  </para>
///	  <para>
///	    1. From projected coordinates to geographic coordinates, (N,E -&gt;
///	    phi,lambda);
///	  </para>
///	  <para>
///	    2. From geographic coordinates to projected coordinates for a model
///	    that supports reverse transformation, (phi,lambda &lt;- N,E).
///	  </para>
///	  <para>
///	    Checking the datum must be done by the user. Accepted ellipsoid are
///	    GRS80, ETRS89 or WGS84 and prime meridian must be Greenwich.
///	  </para>
///	</remarks>
function ModelIsCompatibleToDrawInGoogleEarth(
           const lpModelFileName: PWideChar; const ModelIndex: integer;
           var ErrNo: integer;
           var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM ModelIsCompatibleToDrawInGoogleEarth}

///	<summary>
///	  Returns description informationof the selected transformation modelfrom
///	  a file.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension) this value is
///	  always 1 and for those with more models (files with mtrs or xml extension) can
///	  be 1 up.
///	</param>
///	<param name="ModelDescription">
///	  Structurethat contains the transformation model description returned by
///	  this function.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  The description is read directly from the file and does not consider the
///	  use of the model in reverse.
///	</remarks>
function GetModelDescriptionFromFile(
           const lpModelFileName: PWideChar; const ModelIndex: integer;
           var ModelDescription: TModelDescription;
           var ErrNo: integer;
           var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM GetModelDescriptionFromFile}

///	<summary>
///	  Returns the total number of models froma file.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<returns>
///	  signed 32-bit integer type (result &gt;= 0)
///	</returns>
function GetCountModels(const lpModelFileName: PWideChar): integer; stdcall;
{$EXTERNALSYM GetCountModels}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

///	<summary>
///	  Initialize the transformation of points for a selected transformation
///	  model from a file.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="lpGridFilesPath">
///	  Pointer to a null-terminated string that specifies thepath where grid
///	  files can be found.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension) this value is
///	  always 1 and for those with more models (files with mtrs or xml extension) can
///	  be 1 up.
///	</param>
///	<param name="PlainUMtype">
///	  Value that specifies the type of the plain unit of the coordinates.
///	</param>
///	<param name="UseReversed">
///	  Boolean value that specifies if the model is used reversed or not.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  <para>
///	    1. If you use reversed model and do not know if the model is reversible
///	    or not then you need to test first if the model is reversible or not by
///	    using the function ModelIsReversible.
///	  </para>
///	  <para>
///	    2. Path for grid files is required only for models that use grid files
///	    for coordinates offsets. If the grid files listed inside the model file
///	    are defined with full path then in this case is not necessary to
///	    introduce the search path. Grid files are searched first in the
///	    transformation model directory.
///	  </para>
///	</remarks>
function InitTrPntModel(const lpModelFileName, lpGridFilesPath: PWideChar;
                        const ModelIndex: integer; const PlainUMtype: TPlainUnits;
                        const UseReversed: boolean; var ErrNo: integer;
                        var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM InitTrPntModel}

///	<summary>
///	  Endsthe transformation of points.
///	</summary>
procedure DoneTrPntModel; stdcall;
{$EXTERNALSYM DoneTrPntModel}

///	<summary>
///	  Returns description information of the selected transformation model. The
///	  description is taken from the model was initialized with function
///	  InitTrPntModel.
///	</summary>
///	<param name="ModelDescription">
///	  Structure that contains the transformation model description returned by
///	  this function.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  If at the initialization was used UseReversed value when the initial and
///	  final coordinate system has been already reversed.
///	</remarks>
function GetTrPntModelDescription(var ModelDescription: TModelDescription): boolean; stdcall;
{$EXTERNALSYM GetTrPntModelDescription}

///	<summary>
///	  Set the value of the epoch T0 used to calculate the time difference of the dynamic coordinates.
///	</summary>
///	<param name="EpochT0">
///	  Value of decimal year.
///	</param>
///	<remarks>
///	  If the value is omitted then current date is used.
///	</remarks>
procedure SetTrPntEpochT0(const EpochT0: extended); stdcall;
{$EXTERNALSYM SetTrPntEpochT0}

///	<summary>
///	  Set the value of the epoch T of the dynamic coordinates.
///	</summary>
///	<param name="EpochT">
///	  Value of decimal year.
///	</param>
///	<remarks>
///	  If the value is omitted then current date is used.
///	</remarks>
procedure SetTrPntEpochT(const EpochT: extended); stdcall;
{$EXTERNALSYM SetTrPntEpochT}

///	<summary>
///	  Returns the epoch T0 used to calculate the time difference of the dynamic coordinates.
///	</summary>
///	<param name="EpochT0">
///	  Out value of decimal year.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetTrPntEpochT0(var EpochT0: extended): boolean; stdcall;
{$EXTERNALSYM GetTrPntEpochT0}

///	<summary>
///	  Returns the epoch T of the dynamic coordinates.
///	</summary>
///	<param name="EpochT">
///	  Out value of decimal year.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetTrPntEpochT(var EpochT: extended): boolean; stdcall;
{$EXTERNALSYM GetTrPntEpochT}

///	<summary>
///	  Add a point in the list of points that can be transformed later.
///	</summary>
///	<param name="lpPntName">
///	  Pointer to a null-terminated string that specifies the point name
///	  (number).
///	</param>
///	<param name="XorEorPhi">
///	  Value of X or East or Phi.
///	</param>
///	<param name="YorNorLam">
///	  Value of Y or North or Lambda.
///	</param>
///	<param name="ZorHorHe">
///	  Value of Z or Heigth or Ellipsoidal elevation.
///	</param>
///	<param name="lpPntCode">
///	  Pointer to a null-terminated string that specifies the pointcode (info).
///	</param>
///	<remarks>
///	  <para>
///	    Coordinate systems are: (X,Y,Z) geocentrical, (N,E,H) projection and
///	    (Phi,Lambda,He) geographical.
///	  </para>
///	  <para>
///	    For geographic coordinates the angles must be entered in decimal
///	    degrees [-180.0;+180.0].
///	  </para>
///	</remarks>
procedure AddPoint(const lpPntName: PWideChar;
                   const XorEorPhi, YorNorLam, ZorHorHe: extended;
                   const lpPntCode: PWideChar); stdcall;
{$EXTERNALSYM AddPoint}

///	<summary>
///	  Seta point in the list of points.
///	</summary>
///	<param name="Index">
///	  Integer value that specifies the position of point that will be changed.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a null-terminated string that specifies the point name
///	  (number).
///	</param>
///	<param name="XorEorPhi">
///	  Value of X or East or Phi.
///	</param>
///	<param name="YorNorLam">
///	  Value of Y or North or Lambda.
///	</param>
///	<param name="ZorHorHe">
///	  Value of Z or Heigth or Ellipsoidal elevation.
///	</param>
///	<param name="lpPntCode">
///	  Pointer to a null-terminated string that specifies the point code (info).
///	</param>
///	<remarks>
///	  <para>
///	    Coordinate systems are: (X,Y,Z) geocentrical, (N,E,H) projection and
///	    (Phi,Lambda,He) geographical.
///	  </para>
///	  <para>
///	    For geographic coordinates the angles must be entered in decimal
///	    degrees [-180.0;+180.0].
///	  </para>
///	</remarks>
procedure SetPoint(const Index: integer;
                   const lpPntName: PWideChar;
                   const XorEorPhi, YorNorLam, ZorHorHe: extended;
                   const lpPntCode: PWideChar); stdcall;
{$EXTERNALSYM SetPoint}

///	<summary>
///	  Returns a point from the point list.
///	</summary>
///	<param name="Index">
///	  Integer value that specifies the position of point that will be returned.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a WideChar buffer that containing thepoint name (number).
///	</param>
///	<param name="nMaxPntNameCount">
///	  Indicates the size of the lpPntName buffer.
///	</param>
///	<param name="XorEorPhi">
///	  Outvalue of X or East or Phi.
///	</param>
///	<param name="YorNorLam">
///	  Out value of Y or North or Lambda.
///	</param>
///	<param name="ZorHorHe">
///	  Out value of Z or Heigth or Ellipsoidal elevation.
///	</param>
///	<param name="lpPntCode">
///	  Pointer to a WideChar buffer that containing the pointcode (info).
///	</param>
///	<param name="nMaxPntCodeCount">
///	  Indicates the size of the lpPntCode buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetPoint(const Index: integer;
                  var lpPntName: PWideChar; var nMaxPntNameCount: integer;
                  var XorEorPhi, YorNorLam, ZorHorHe: extended;
                  var lpPntCode: PWideChar; var nMaxPntCodeCount: integer): boolean; stdcall;
{$EXTERNALSYM GetPoint}

///	<summary>
///	  Returnscoordinates as formatted text to a pointfrom the point list.
///	</summary>
///	<param name="Index">
///	  Integer value that specifies the position of point that will be returned.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a WideChar buffer that containing the point name (number).
///	</param>
///	<param name="nMaxPntNameCount">
///	  Indicates the size of the lpPntName buffer.
///	</param>
///	<param name="lpXorEorPhi">
///	  Pointer to a WideChar buffer that containing theformated coordinate X or
///	  East or Phi.
///	</param>
///	<param name="nMaxXorEorPhiCount">
///	  Indicates the size of the lpXorEorPhi buffer.
///	</param>
///	<param name="lpYorNorLam">
///	  Pointer to a WideChar buffer that containing the formated coordinate Y or
///	  North or Lambda.
///	</param>
///	<param name="nMaxYorNorLamCount">
///	  Indicates the size of the lpYorNorLam buffer.
///	</param>
///	<param name="lpZorHorHe">
///	  Pointer to a WideChar buffer that containing the formated coordinate Z or
///	  Heigth or Ellipsoidal elevation.
///	</param>
///	<param name="nMaxZorHorHeCount">
///	  Indicates the size of the lpZorHorHe buffer.
///	</param>
///	<param name="lpPntCode">
///	  Pointer to a WideChar buffer that containing the pointcode (info).
///	</param>
///	<param name="nMaxPntCodeCount">
///	  Indicates the size of the lpPntCode buffer.
///	</param>
///	<param name="AngleAspect">
///	  Structure thatspecifies how anglesare writein the case of geographic
///	  coordinate.
///	</param>
///	<param name="DecNoXYZ">
///	  Number of decimals for the geocentric coordinates (X,Y,Z).
///	</param>
///	<param name="DecNoNEH">
///	  Number of decimals for projected plane coordinates (N,E,H).
///	</param>
///	<param name="DecNoGeoHe">
///	  Number of decimals for the ellipsoidal elevation (He).
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  If transformation was not made when the coordinates are formatted
///	  according to the initial coordinate system and if the transformation was
///	  made when formatting is under final coordinate system.
///	</remarks>
function GetPointFormated(const Index: integer;
                          var lpPntName  : PWideChar; var nMaxPntNameCount  : integer;
                          var lpXorEorPhi: PWideChar; var nMaxXorEorPhiCount: integer;
                          var lpYorNorLam: PWideChar; var nMaxYorNorLamCount: integer;
                          var lpZorHorHe : PWideChar; var nMaxZorHorHeCount : integer;
                          var lpPntCode  : PWideChar; var nMaxPntCodeCount  : integer;
                          const AngleAspect: TAngleAspect;
                          const DecNoXYZ, DecNoNEH, DecNoGeoHe: integer): boolean; stdcall;
{$EXTERNALSYM GetPointFormated}

///	<summary>
///	  Delete a point from the point list.
///	</summary>
///	<param name="Index">
///	  Integer value that specifies the position of point that will be deleted.
///	</param>
procedure DeletePoint(const Index: integer); stdcall;
{$EXTERNALSYM DeletePoint}

///	<summary>
///	  Delete all points from the point list.
///	</summary>
procedure DeleteAllPoints; stdcall;
{$EXTERNALSYM DeleteAllPoints}

///	<summary>
///	  Return the total number of the point list.
///	</summary>
///	<returns>
///	  signed 32-bit integer type (result &gt;= 0)
///	</returns>
function GetCountPoints: integer; stdcall;
{$EXTERNALSYM GetCountPoints}

///	<summary>
///	  <para>
///	    Load points from a text file. Coordinates can be separated by spaces,
///	    comma or a specified character.
///	  </para>
///	  <para>
///	    The orderon line is: PointName, Ordinate 1, Ordinate 2, Ordinate 3 (if
///	    exists)andPointCode.
///	  </para>
///	  <para>
///	    For geographical coordinates normal order is Phi, Lambda and for
///	    projected coordinates is N, E.
///	  </para>
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file namefor load.
///	</param>
///	<param name="InvertAxes12">
///	  <para>
///	    Boolean value that specifies if the ordinate 1with 2are reversed.
///	  </para>
///	  <para>
///	    Axis inversion is possible only in the case of geographic or projected
///	    coordinates.
///	  </para>
///	</param>
///	<param name="AngleAspect">
///	  Structure that specifies how angles are write in the case of geographic
///	  coordinate.
///	</param>
///	<param name="PlainUMtype">
///	  Value that specifies the type of the plain unit of the coordinates. Used
///   for xml coordinates files.
///	<param name="ChCsv">
///	  WideCharvalue that specifies theseparator of the fields from the file.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function LoadPointsFromFile(const lpFileName: PWideChar; const InvertAxes12: boolean;
                            const AngleAspect: TAngleAspect; const PlainUMtype: TPlainUnits;
                            const ChCsv: WideChar; var ErrNo: integer;
                            var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM LoadPointsFromFile}
         ///	<summary>
///	  Savepointsto a text file.
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file name for save.
///	</param>
///	<param name="FixCoo">
///	  <para>
///	    Boolean value that specifies if the saved coordinates are fixed or not
///     to the number of decimals.
///	  </para>
///	</param>
///	<param name="InvertAxes12">
///	  <para>
///	    Boolean value that specifies if the ordinate 1 with 2 are reversed.
///	  </para>
///	  <para>
///	    Axis inversion is possible only in the case of geographic or projected
///	    coordinates.
///	  </para>
///	</param>
///	<param name="AngleAspect">
///	  Structure that specifies how angles are write in the case of geographic
///	  coordinate.
///	</param>
///	<param name="PlainUMtype">
///	  Value that specifies the type of the plain unit of the coordinates. Used
///   for xml coordinates files.
///	</param>
///	<param name="ChCsv">
///	  WideChar value that specifies the separator of the fields from the file.
///	</param>
///	<param name="DecNoXYZ">
///	  Number of decimals for the geocentric coordinates (X,Y,Z).
///	</param>
///	<param name="DecNoNEH">
///	  Number of decimals for projected plane coordinates (N,E,H).
///	</param>
///	<param name="DecNoGeoHe">
///	  Number of decimals for the ellipsoidal elevation (He).
///	</param>
///	<param name="EncodingType">
///	  Enter the type of encoding from TEncodingType enumeration. The file will
///	  be saved with this encoding type.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function SavePointsToFile(const lpFileName: PWideChar; const FixCoo, InvertAxes12: boolean;
                          const AngleAspect: TAngleAspect; const PlainUMtype: TPlainUnits;
                          const ChCsv: WideChar; const DecNoXYZ, DecNoNEH, DecNoGeoHe: integer;
                          const EncodingType: TEncodingType): boolean; stdcall;
{$EXTERNALSYM SavePointsToFile}

///	<summary>
///	  Transform coordinates from the list of points.
///	</summary>
///	<param name="ProgressProc">
///	  Pointer to a callback function. In this function you must display the
///	  percentage of the process.
///	</param>
///	<param name="lpStrCooOp">
///	  <para>
///	    Pointer to a null-terminated string that specifies in your language the
///	    text "Coordinate Operation".
///	  </para>
///	  <para>
///	    Text is used to indicate in which coordinates operation an error
///	    occurred.
///	  </para>
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function TransformPoints(ProgressProc: TProgressProc;
                         const lpStrCooOp: PWideChar;
                         var ErrNo: integer;
                         var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM TransformPoints}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

///	<summary>
///	  Initialize the transformation of entitiesand to drawing them in Google
///	  Earth for a selected transformation model from a file.
///	</summary>
///	<param name="lpModelFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  transformation models, file with mtr, mtrs or xml extension. Files can be
///	  created and saved with TransLT program.
///	</param>
///	<param name="lpGridFilesPath">
///	  Pointer to a null-terminated string that specifies the path where grid
///	  files can be found.
///	</param>
///	<param name="ModelIndex">
///	  For files with a single model (files with mtr extension) this value is
///	  always 1 and for those with more models (files with mtrs or xml extension) can
///	  be 1 up.
///	</param>
///	<param name="PlainUMtype">
///	  Value that specifies the type of the plain unit of the coordinates.
///	</param>
///	<param name="UseReversed">
///	  Boolean value that specifies if the model is used reversed or not.
///	</param>
///	<param name="GEEntLangWords">
///	  Structure that contains the texts in your language with the default names
///	  for "My Place", "Polygon - No name", "Path - No name" and "Group points -
///	  No name". These texts are used for nameless placeor entities.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  <para>
///	    1. If you use reversed model and do not know if the model is reversible
///	    or not then you need to test first if the model is reversible or not by
///	    using the function ModelIsReversible.
///	  </para>
///	  <para>
///	    2. Path for grid files is required only for models that use grid files
///	    for coordinates offsets. If the grid files listed inside the model file
///	    are defined with full path then in this case is not necessary to
///	    introduce the search path. Grid files are searched first in the
///	    transformation model directory.
///	  </para>
///	  <para>
///	    3. In the case of models which are used for drawing in Google Earth is
///	    testing if the model is compatible or not for this command. The model
///	    is compatible if it can make make a transformation from projected
///	    coordinate system to geographical coordinate system: (N,E -&gt;
///	    phi,lambda) or reversed (phi,lambda &lt;- N,E). Same note at the
///	    function ModelIsCompatibleToDrawInGoogleEarth.
///	  </para>
///	</remarks>
function InitTrGEModel(const lpModelFileName, lpGridFilesPath: PWideChar;
                       const ModelIndex: integer; const PlainUMtype: TPlainUnits;
                       const UseReversed: boolean;
                       const GEEntLangWords: TGEEntLangWords;
                       var ErrNo: integer;
                       var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM InitTrGEModel}

///	<summary>
///	  Ends the transformation and drawing of entities.
///	</summary>
procedure DoneTrGEModel; stdcall;
{$EXTERNALSYM DoneTrGEModel}

///	<summary>
///	  Returns description information of the selected transformation model. The
///	  description is taken from the model was initialized with function
///	  InitTrGEModel.
///	</summary>
///	<param name="ModelDescription">
///	  Structure that contains the transformation model description returned by
///	  this function.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  If at the initialization was used UseReversed value when the initial and
///	  final coordinate system has been already reversed.
///	</remarks>
function GetTrGEModelDescription(var ModelDescription: TModelDescription): boolean; stdcall;
{$EXTERNALSYM GetTrGEModelDescription}

///	<summary>
///	  Set the value of the epoch T0 used to calculate the time difference of the dynamic coordinates.
///	</summary>
///	<param name="EpochT0">
///	  Value of decimal year.
///	</param>
///	<remarks>
///	  If the value is omitted then current date is used.
///	</remarks>
procedure SetTrGEEpochT0(const EpochT0: extended); stdcall;
{$EXTERNALSYM SetTrGEEpochT0}

///	<summary>
///	  Set the value of the epoch T of the dynamic coordinates.
///	</summary>
///	<param name="EpochT">
///	  Value of decimal year.
///	</param>
///	<remarks>
///	  If the value is omitted then current date is used.
///	</remarks>
procedure SetTrGEEpochT(const EpochT: extended); stdcall;
{$EXTERNALSYM SetTrGEEpochT}

///	<summary>
///	  Returns the epoch T0 used to calculate the time difference of the dynamic coordinates.
///	</summary>
///	<param name="EpochT0">
///	  Out value of decimal year.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetTrGEEpochT0(var EpochT0: extended): boolean; stdcall;
{$EXTERNALSYM GetTrGEEpochT0}

///	<summary>
///	  Returns the epoch T of the dynamic coordinates.
///	</summary>
///	<param name="EpochT">
///	  Out value of decimal year.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetTrGEEpochT(var EpochT: extended): boolean; stdcall;
{$EXTERNALSYM GetTrGEEpochT}

///	<summary>
///	  Add anentity in the list of entities that can be transformed or drawn in
///	  Google Earthlater.
///	</summary>
///	<param name="GEEntityProperties">
///	  Structure in which will specify all information regarding to the newly
///	  created entity.
///	</param>
procedure AddGEEntity(const GEEntityProperties: TGEEntityProperties); stdcall;
{$EXTERNALSYM AddGEEntity}

///	<summary>
///	  Set an entity in the list of entities.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position ofentity that will be changed.
///	</param>
///	<param name="GEEntityProperties">
///	  Structure in which will specify all information regarding to the newly
///	  created entity.
///	</param>
procedure SetGEEntity(const EntIndex: integer;
                      const GEEntityProperties: TGEEntityProperties); stdcall;
{$EXTERNALSYM SetGEEntity}

///	<summary>
///	  Deletean entityfrom the list of entities.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity that will be deleted.
///	</param>
procedure DeleteGEEntity(const EntIndex: integer); stdcall;
{$EXTERNALSYM DeleteGEEntity}

///	<summary>
///	  Returns anentity from theentities list.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position ofentity that will be returned.
///	</param>
///	<param name="GEEntityProperties">
///	  Structure in which are returnedall information about the entity.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetGEEntity(const EntIndex: integer;
                     var GEEntityProperties: TGEEntityProperties): boolean; stdcall;
{$EXTERNALSYM GetGEEntity}

///	<summary>
///	  Delete all entities from list.
///	</summary>
procedure ClearGEEntities; stdcall;
{$EXTERNALSYM ClearGEEntities}

///	<summary>
///	  Return the total number of entities from list.
///	</summary>
///	<returns>
///	  signed 32-bit integer type (result &gt;= 0)
///	</returns>
function GetCountGEEntites: integer; stdcall;
{$EXTERNALSYM GetCountGEEntites}

///	<summary>
///	  Add a point in the points listof an entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a null-terminated string that specifies the point name (number)
///	</param>
///	<param name="EorPhi">
///	  Value of East or Phi.
///	</param>
///	<param name="NorLam">
///	  Value of North or Lambda.
///	</param>
procedure AddPointToGEEntity(const EntIndex: integer;
                             const lpPntName: PWideChar;
                             const EorPhi, NorLam: extended); stdcall;
{$EXTERNALSYM AddPointToGEEntity}

///	<summary>
///	  Seta point in the points list of an entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<param name="PntIndex">
///	  Integer value that specifies the position of pointthat will be changed.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a null-terminated string that specifies the point name (number)
///	</param>
///	<param name="EorPhi">
///	  Value of East or Phi.
///	</param>
///	<param name="NorLam">
///	  Value of North or Lambda.
///	</param>
procedure SetPointToGEEntity(const EntIndex, PntIndex: integer;
                             const lpPntName: PWideChar;
                             const EorPhi, NorLam: extended); stdcall;
{$EXTERNALSYM SetPointToGEEntity}

///	<summary>
///	  Returna pointfrom thepoints list of an entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<param name="PntIndex">
///	  Integer value that specifies the position of point that will be returned.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a WideChar buffer that containing the point name (number).
///	</param>
///	<param name="nMaxPntNameCount">
///	  Indicates the size of the lpPntName buffer.
///	</param>
///	<param name="EorPhi">
///	  Out value ofEast or Phi.
///	</param>
///	<param name="NorLam">
///	  Out value ofNorth or Lambda.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetPointFromGEEntity(const EntIndex, PntIndex: integer;
                              var lpPntName: PWideChar; var nMaxPntNameCount: integer;
                              var EorPhi, NorLam: extended): boolean; stdcall;
{$EXTERNALSYM GetPointFromGEEntity}

///	<summary>
///	  Returns coordinates as formatted text to a point from the point list of
///	  an entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<param name="PntIndex">
///	  Integer value that specifies the position of point that will be returned.
///	</param>
///	<param name="lpPntName">
///	  Pointer to a WideChar buffer that containing the point name (number).
///	</param>
///	<param name="nMaxPntNameCount">
///	  Indicates the size of the lpPntName buffer.
///	</param>
///	<param name="lpEorPhi">
///	  Pointer to a WideChar buffer that containing the formated coordinateEast
///	  or Phi.
///	</param>
///	<param name="nMaxEorPhiCount">
///	  Indicates the size of the lpEorPhi buffer.
///	</param>
///	<param name="lpNorLam">
///	  Pointer to a WideChar buffer that containing the formated coordinate
///	  North or Lambda.
///	</param>
///	<param name="nMaxNorLamCount">
///	  Indicates the size of the lpNorLam buffer.
///	</param>
///	<param name="CoordIsGeog">
///	  Boolean value that specifies if thecoordinates isgeographical or not.
///	</param>
///	<param name="AngleAspect">
///	  Structure that specifies how angles are write in the case of geographic
///	  coordinate.
///	</param>
///	<param name="DecNoNEH">
///	  Number of decimals for projected plane coordinates (N,E,H).
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function GetPointFromGEEntityFormated(const EntIndex, PntIndex: integer;
                    var lpPntName: PWideChar; var nMaxPntNameCount: integer;
                    var lpEorPhi: PWideChar; var nMaxEorPhiCount: integer;
                    var lpNorLam: PWideChar; var nMaxNorLamCount: integer;
                    const CoordIsGeog: boolean; const AngleAspect: TAngleAspect;
                    const DecNoNEH: integer): boolean; stdcall;
{$EXTERNALSYM GetPointFromGEEntityFormated}

///	<summary>
///	  Return the total number ofpoints of an entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<returns>
///	  signed 32-bit integer type (result &gt;= 0)
///	</returns>
function GetCountPointsOfGEEntity(const EntIndex: integer): integer; stdcall;
{$EXTERNALSYM GetCountPointsOfGEEntity}

///	<summary>
///	  Delete allpointsofan entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
procedure DeleteAllPointsOfGEEntity(const EntIndex: integer); stdcall;
{$EXTERNALSYM DeleteAllPointsOfGEEntity}

///	<summary>
///	  Calculate the area and length (perimeter) of an entity. Values are set in
///	  the structure with information about the entity.
///	</summary>
///	<param name="EntIndex">
///	  Integer value that specifies the position of entity.
///	</param>
///	<param name="AreaUMtype">
///	  Value that specifies the type of the area unit.
///	</param>
///	<param name="AreaDecNo">
///	  Number of decimals for area.
///	</param>
///	<param name="LengthUMtype">
///	  Value that specifies the type of the plain unit of the length.
///	</param>
///	<param name="LengthDecNo">
///	  Number of decimals for length.
///	</param>
///	<remarks>
///	  This calculation is made only when the coordinates of entities are
///	  projected, in geographical coordinates this calculation is wrong.
///	  Checking this must be done by the user.
///	</remarks>
procedure CalculateAreaAndLengthToGEEntity(const EntIndex: integer;
                  const AreaUMtype: TAreaUnits; const AreaDecNo: integer;
                  const LengthUMtype: TPlainUnits; const LengthDecNo: integer); stdcall;
{$EXTERNALSYM CalculateAreaAndLengthToGEEntity}

///	<summary>
///	  Load entities from csv or xml file. The format of the file must comply the
///	  TransLT file format (file with entities inside).
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file with
///	  entities. Extension of the file can be: csv, xml, kml or kmz.
///	</param>
///	<param name="InvertAxes12">
///	  Boolean value that specifies if the ordinate 1 with 2 are reversed. Axis
///	  inversion is possible only in the case of geographic or projected
///	  coordinates.
///	</param>
///	<param name="AngleAspect">
///	  Structure that specifies how angles are write in the case of geographic
///	  coordinate.
///	</param>
///	<param name="ChCsv">
///	  WideChar value that specifies the separator of the fields from the file.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function LoadGEEntitiesFromFile(const lpFileName: PWideChar; const InvertAxes12: boolean;
                                const AngleAspect: TAngleAspect; const ChCsv: WideChar;
                                var ErrNo: integer;
                                var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM LoadGEEntitiesFromFile}

///	<summary>
///	  Save allentities to file. Saving data can be made for for types of
///	  files: csv (TransLT format with entities), xml (Extensible Markup
///   Language), kml (Uncompressed Google Earth format) or kmz(Compressed
///   Google Earth format). The file format is chosen by its extension.
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file where the
///   entities are saved. Extension of the file can be csv, xml, kml or kmz.
///	</param>
///	<param name="lpProgName">
///	  Pointer to a null-terminated string that specifies your program name.
///	  This value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpProgVer">
///	  Pointer to a null-terminated string that specifies your program version.
///	  This value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpWebPage">
///	  Pointer to a null-terminated string that specifies your web page. This
///	  value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpPlaceName">
///	  Pointer to a null-terminated string that specifies the place name for all
///	  entities. This value is written in the list with places in Google Earth.
///	</param>
///	<param name="InvertAxes12">
///	  Boolean value that specifies if the ordinate 1 with 2 are reversed. Axis
///	  inversion is possible only in the case of geographic or projected
///	  coordinates.
///	</param>
///	<param name="AngleAspect">
///	  Structure that specifies how angles are write in the case of geographic
///	  coordinate.
///	</param>
///	<param name="ChCsv">
///	  WideChar value that specifies the separator of the fields from the file.
///	</param>
///	<param name="GEDrawOptions">
///	  Structure that specifies all Google Earthdrawing options.
///	</param>
///	<param name="GEKmlLangWords">
///	  Structure that contains the texts in your language with the default texts
///	   for entitiy properties. This texts is written in the description balloon
///	  in Google Earth.
///	</param>
///	<param name="EncodingType">
///	  Enter the type of encoding from TEncodingType enumeration. The file will
///	  be saved with this encoding type.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function SaveGEEntitiesToFile(const lpFileName, lpProgName, lpProgVer, lpWebPage, lpPlaceName: PWideChar;
                              const InvertAxes12: boolean;
                              const AngleAspect: TAngleAspect; const ChCsv: WideChar;
                              const GEDrawOptions: TGEDrawOptions;
                              const GEKmlLangWords: TGEKmlLangWords;
                              const EncodingType: TEncodingType;
                              var ErrNo: integer;
                              var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM SaveGEEntitiesToFile}

///	<summary>
///	  Draw all entities in Google Earth. This command only works if Google
///	  Earth is installed on your computer, otherwise an error occurs.
///   Return true if the temporary file is created.
///	</summary>
///	<param name="lpProgName">
///	  Pointer to a null-terminated string that specifies your program name.
///	  This value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpProgVer">
///	  Pointer to a null-terminated string that specifies your program version.
///	  This value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpWebPage">
///	  Pointer to a null-terminated string that specifies your web page. This
///	  value is written in the description balloon in Google Earth.
///	</param>
///	<param name="lpPlaceName">
///	  Pointer to a null-terminated string that specifies the place name for all
///	  entities. This value is written in the list with places in Google Earth.
///	</param>
///	<param name="lpTempFileName">
///	  Pointer to a null-terminated string that specifies the name of the temporary
///   file. If an empty string is entered then the name is generated automatically.
///   If the file does not contain the path then the path will be in the temporary
///   Windows directory. At the end of the work session and after Google Earth has
///   loaded this file, all the temporary files created by this command can be
///   deleted with the ClearTempFilesGE procedure.
///	</param>
///	<param name="GEDrawOptions">
///	  Structure that specifies all Google Earth drawing options.
///	</param>
///	<param name="GEKmlLangWords">
///	  Structure that contains the texts in your language with the default texts
///	  for entitiy properties. This texts is written in the description balloon
///	  in Google Earth.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function DrawGEEntitiesToGoogleEarth(const lpProgName, lpProgVer, lpWebPage, lpPlaceName, lpTempFileName: PWideChar;
                                     const GEDrawOptions: TGEDrawOptions;
                                     const GEKmlLangWords: TGEKmlLangWords;
                                     var ErrNo: integer;
                                     var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM DrawGEEntitiesToGoogleEarth}

///	<summary>
///   Save in file the information for which Google Earth will zoom on the
///   coordinates of a rectangle.
///	</summary>
///	<param name="lpFileName">
///	  Pointer to a null-terminated string that specifies the file where the
///   entities are saved. Extension of the file can be only kml.
///	</param>
///	<param name="lpFolderName">
///	  Pointer to a null-terminated string that specifies the Google Earth
///   folder name.
///	</param>
///	<param name="PhiMin">
///	  The geographic latitude of the lower-left corner.
///	</param>
///	<param name="LamMin">
///	  The geographic longitude of the lower-left corner.
///	</param>
///	<param name="PhiMax">
///	  The geographic latitude of the upper-right corner.
///	</param>
///	<param name="LamMax">
///	  The geographic longitude of the upper-right corner.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
function SaveGEZoomToFile(const lpFileName: PWideChar;
                          const lpFolderName: PWideChar;
                          const PhiMin, LamMin, PhiMax, LamMax: extended): boolean; stdcall;
{$EXTERNALSYM SaveGEZoomToFile}

///	<summary>
///	  Draw in Google Earth the information for which Google Earth will zoom on the
///   coordinates of a rectangle. This command only works if Google Earth is
///   installed on your computer, otherwise an error occurs.
///   Return true if the temporary file is created.
///	<param name="lpTempFileName">
///	  Pointer to a null-terminated string that specifies the name of the temporary
///   file. If an empty string is entered then the name is generated automatically.
///   If the file does not contain the path then the path will be in the temporary
///   Windows directory. At the end of the work session and after Google Earth has
///   loaded this file, all the temporary files created by this command can be
///   deleted with the ClearTempFilesGE procedure.
///	<param name="lpFolderName">
///	  Pointer to a null-terminated string that specifies the Google Earth
///   folder name.
///	</param>
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
function DrawGEZoomToGoogleEarth(const lpTempFileName: PWideChar;
                                 const lpFolderName: PWideChar;
                                 const PhiMin, LamMin, PhiMax, LamMax: extended;
                                 var ErrNo: integer;
                                 var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM DrawGEZoomToGoogleEarth}

///	<summary>
///	  Delete all temporary files used for drawing entities in Google Earth.
///   Useful procedure at the end of the work session.
///	</summary>
procedure ClearTempFilesGE; stdcall;
{$EXTERNALSYM ClearTempFilesGE}

///	<summary>
///	  Transform coordinates of points from all entities.
///	</summary>
///	<param name="ProgressProc">
///	  Pointer to a callback function. In this function you must display the
///	  percentage of the process.
///	</param>
///	<param name="lpStrCooOp">
///	  Pointer to a null-terminated string that specifies in your language the
///	  text "Coordinate Operation". Text is used to indicate in which
///	  coordinates operation an error occurred.
///	</param>
///	<param name="ErrNo">
///	  Number greater than 0 that corresponds to the line number from the file
///	  with errors "TransLT-....err".
///	</param>
///	<param name="lpErrTxt">
///	  Pointer to a WideChar buffer that containing the message error.
///	</param>
///	<param name="nMaxCount">
///	  Indicates the size of the lpErrTxt buffer.
///	</param>
///	<returns>
///	  Boolean
///	</returns>
///	<remarks>
///	  To make this transformation of the points of entities points must be
///	  entered as projected coordinates (N,E). Conversion should be made from
///	  projected coordinates to geographic coordinates.
///	</remarks>
function TransformPointsOfAllGEEntities(ProgressProc: TProgressProc;
                                        const lpStrCooOp: PWideChar;
                                        var ErrNo: integer;
                                        var lpErrTxt: PWideChar; var nMaxCount: integer): boolean; stdcall;
{$EXTERNALSYM TransformPointsOfAllGEEntities}

//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------------------------

implementation

//----------------------------------------------------------------------------------------------------------------------
//Functions of language settings for error messages
function  SetErrMsgFileName; external TRLTDLLFILE name 'SetErrMsgFileName';
procedure GetErrMsgFileName; external TRLTDLLFILE name 'GetErrMsgFileName';

//----------------------------------------------------------------------------------------------------------------------
//Functions about model properties read from mtr, mtrs or xml (model or models) file
function  ModelFileIsCompatible; external TRLTDLLFILE name 'ModelFileIsCompatible';
function  ModelHasCooOperations; external TRLTDLLFILE name 'ModelHasCooOperations';
function  ModelIsReversible; external TRLTDLLFILE name 'ModelIsReversible';
function  ModelIsCompatibleToDrawInGoogleEarth; external TRLTDLLFILE name 'ModelIsCompatibleToDrawInGoogleEarth';
function  GetModelDescriptionFromFile; external TRLTDLLFILE name 'GetModelDescriptionFromFile';
function  GetCountModels; external TRLTDLLFILE name 'GetCountModels';

//----------------------------------------------------------------------------------------------------------------------
//Functions for transforming coordinates of points
function  InitTrPntModel; external TRLTDLLFILE name 'InitTrPntModel';
procedure DoneTrPntModel; external TRLTDLLFILE name 'DoneTrPntModel';
function  GetTrPntModelDescription; external TRLTDLLFILE name 'GetTrPntModelDescription';
procedure SetTrPntEpochT0; external TRLTDLLFILE name 'SetTrPntEpochT0';
procedure SetTrPntEpochT; external TRLTDLLFILE name 'SetTrPntEpochT';
function GetTrPntEpochT0; external TRLTDLLFILE name 'GetTrPntEpochT0';
function GetTrPntEpochT; external TRLTDLLFILE name 'GetTrPntEpochT';
procedure AddPoint; external TRLTDLLFILE name 'AddPoint';
procedure SetPoint; external TRLTDLLFILE name 'SetPoint';
function  GetPoint; external TRLTDLLFILE name 'GetPoint';
function  GetPointFormated; external TRLTDLLFILE name 'GetPointFormated';
procedure DeletePoint; external TRLTDLLFILE name 'DeletePoint';
procedure DeleteAllPoints; external TRLTDLLFILE name 'DeleteAllPoints';
function  GetCountPoints; external TRLTDLLFILE name 'GetCountPoints';
function  LoadPointsFromFile; external TRLTDLLFILE name 'LoadPointsFromFile';
function  SavePointsToFile; external TRLTDLLFILE name 'SavePointsToFile';
function  TransformPoints; external TRLTDLLFILE name 'TransformPoints';

//----------------------------------------------------------------------------------------------------------------------
//Functions for transforming coordinates of points of entities (if is necessary)
//and for drawing entities in Google Earth
function  InitTrGEModel; external TRLTDLLFILE name 'InitTrGEModel';
procedure DoneTrGEModel; external TRLTDLLFILE name 'DoneTrGEModel';
function  GetTrGEModelDescription; external TRLTDLLFILE name 'GetTrGEModelDescription';
procedure SetTrGEEpochT0; external TRLTDLLFILE name 'SetTrGEEpochT0';
procedure SetTrGEEpochT; external TRLTDLLFILE name 'SetTrGEEpochT';
function GetTrGEEpochT0; external TRLTDLLFILE name 'GetTrGEEpochT0';
function GetTrGEEpochT; external TRLTDLLFILE name 'GetTrGEEpochT';
procedure AddGEEntity; external TRLTDLLFILE name 'AddGEEntity';
procedure SetGEEntity; external TRLTDLLFILE name 'SetGEEntity';
procedure DeleteGEEntity; external TRLTDLLFILE name 'DeleteGEEntity';
function  GetGEEntity; external TRLTDLLFILE name 'GetGEEntity';
procedure ClearGEEntities; external TRLTDLLFILE name 'ClearGEEntities';
function  GetCountGEEntites; external TRLTDLLFILE name 'GetCountGEEntites';
procedure AddPointToGEEntity; external TRLTDLLFILE name 'AddPointToGEEntity';
procedure SetPointToGEEntity; external TRLTDLLFILE name 'SetPointToGEEntity';
function  GetPointFromGEEntity; external TRLTDLLFILE name 'GetPointFromGEEntity';
function  GetPointFromGEEntityFormated; external TRLTDLLFILE name 'GetPointFromGEEntityFormated';
function  GetCountPointsOfGEEntity; external TRLTDLLFILE name 'GetCountPointsOfGEEntity';
procedure DeleteAllPointsOfGEEntity; external TRLTDLLFILE name 'DeleteAllPointsOfGEEntity';
procedure CalculateAreaAndLengthToGEEntity; external TRLTDLLFILE name 'CalculateAreaAndLengthToGEEntity';
function  LoadGEEntitiesFromFile; external TRLTDLLFILE name 'LoadGEEntitiesFromFile';
function  SaveGEEntitiesToFile; external TRLTDLLFILE name 'SaveGEEntitiesToFile';
function  DrawGEEntitiesToGoogleEarth; external TRLTDLLFILE name 'DrawGEEntitiesToGoogleEarth';
function  SaveGEZoomToFile; external TRLTDLLFILE name 'SaveGEZoomToFile';
function  DrawGEZoomToGoogleEarth; external TRLTDLLFILE name 'DrawGEZoomToGoogleEarth';
procedure ClearTempFilesGE; external TRLTDLLFILE name 'ClearTempFilesGE';
function  TransformPointsOfAllGEEntities; external TRLTDLLFILE name 'TransformPointsOfAllGEEntities';

//----------------------------------------------------------------------------------------------------------------------

end.
